============
Installation
============

At the command line::

    $ easy_install django-next-url-mixin

Or, if you have virtualenvwrapper installed::

    $ mkvirtualenv django-next-url-mixin
    $ pip install django-next-url-mixin
